@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+/* -*- MODE: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /* Author: Chris Lahey <clahey@umich.edu>
  * Based on capplets/bell-properties/bell-properties.c.
  */
@@ -169,7 +169,7 @@ edit_help(void)
 {
   gchar *tmp;
 
-  tmp = gnome_help_file_find_file ("users-guide", "gccedit.html");
+  tmp = gnome_help_file_find_file ("control-center", "doc-handlers.html#GCCEDIT");
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
