@@ -7,10 +7,10 @@
 void capplet_corba_gtk_main (void);
 void capplet_corba_gtk_main_quit (void);
 void capplet_corba_state_changed (gint id, gboolean undoable);
-guint32 get_xid (gint cid);
-gint get_ccid (gint cid);
-gint get_capid ();
-gint session_initialization_requested_p(void);
+guint32 _capplet_int_get_xid (gint cid);
+gint _capplet_int_get_ccid (gint cid);
+gint _capplet_int_get_capid ();
+gint _capplet_int_session_initialization_requested_p(void);
 void *capplet_widget_corba_init(const char *app_id,
                                const char *app_version,
                                int *argc, char **argv,
